@@ -57,23 +57,6 @@ default:
 $max = array_fetch ($options, 'max', 0);
 $nolock = array_key_exists ('nolock', $options);
 
-$switch_list = array();
-if (! isset ($options['vdid']))
-	$switch_list = getVLANSwitches();
-else
-	try
-	{
-		$mydomain = getVLANDomain ($options['vdid']);
-		foreach ($mydomain['switchlist'] as $switch)
-			$switch_list[] = $switch['object_id'];
-	}
-	catch (RackTablesError $e)
-	{
-		print_message_line ("Cannot load domain data with ID ${options['vdid']}");
-		print_message_line ($e->getMessage());
-		exit (1);
-	}
-
 $todo = array
 (
 	'pull' => array ('sync_ready', 'resync_ready'),
@@ -119,20 +102,32 @@ if (! $nolock)
 }
 
 // fetch all the needed data from DB (preparing for DB connection loss)
+$vswitch_filter = array();
+if (isset ($options['vdid']))
+	$vswitch_filter['domain_id'] = $options['vdid'];
+$switch_list = getVLANSwitchInfoRows ($vswitch_filter);
+$enabled_switches = listConstraint ('object', 'SYNC_802Q_LISTSRC');
+
 $switch_queue = array();
-foreach ($switch_list as $object_id)
+foreach ($switch_list as $vswitch)
 {
-	$cell = spotEntity ('object', $object_id);
-	$new_disabled = ! considerConfiguredConstraint ($cell, 'SYNC_802Q_LISTSRC');
-	$queue = detectVLANSwitchQueue (getVLANSwitchInfo ($object_id));
-	if ($queue == 'disabled' xor $new_disabled)
-		usePreparedExecuteBlade
-		(
-			'UPDATE VLANSwitch SET out_of_sync="yes", last_error_ts=NOW(), last_errno=? WHERE object_id=?',
-			array ($new_disabled ? E_8021Q_SYNC_DISABLED : E_8021Q_NOERROR, $object_id)
-		);
-	elseif (in_array ($queue, $todo[$options['mode']]))
-		$switch_queue[] = $cell;
+	$object_id = $vswitch['object_id'];
+	$new_disabled = ! isset ($enabled_switches[$object_id]);
+	$queue = detectVLANSwitchQueue ($vswitch);
+	if ($queue != 'disabled' && $new_disabled)
+	{
+		setVLANSwitchError ($object_id, E_8021Q_SYNC_DISABLED);
+		continue;
+	}
+	elseif ($queue == 'disabled' && ! $new_disabled)
+	{
+		$vswitch['last_errno'] = E_8021Q_NOERROR;
+		setVLANSwitchError ($object_id, $vswitch['last_errno']);
+		$queue = detectVLANSwitchQueue ($vswitch);
+	}
+
+	if (in_array ($queue, $todo[$options['mode']]))
+		$switch_queue[] = spotEntity ('object', $object_id);
 }
 
 // YOU SHOULD NOT USE DB FUNCTIONS BELOW IN THE PARENT PROCESS
