@@ -187,33 +187,28 @@ function assertPermission ($p = NULL, $t = NULL, $o = NULL, $annex = array())
 function gotClearanceForTagChain ($const_base)
 {
 	global $rackCode, $expl_tags, $impl_tags;
-	$ptable = array();
+	$context = array_merge ($const_base, $expl_tags, $impl_tags);
+	$context = reindexById ($context, 'tag', TRUE);
+
 	foreach ($rackCode as $sentence)
 	{
 		switch ($sentence['type'])
 		{
-			case 'SYNT_DEFINITION':
-				$ptable[$sentence['term']] = $sentence['definition'];
-				break;
 			case 'SYNT_GRANT':
-				if (eval_expression ($sentence['condition'], array_merge ($const_base, $expl_tags, $impl_tags), $ptable))
-					switch ($sentence['decision'])
-					{
-						case 'LEX_ALLOW':
-							return TRUE;
-						case 'LEX_DENY':
-							return FALSE;
-						default:
-							throw new RackTablesError ("Condition match for unknown grant decision '${sentence['decision']}'", RackTablesError::INTERNAL);
-					}
+				if (eval_expression ($sentence['condition'], $context))
+					return $sentence['decision'];
 				break;
 			case 'SYNT_ADJUSTMENT':
 				if
 				(
-					eval_expression ($sentence['condition'], array_merge ($const_base, $expl_tags, $impl_tags), $ptable) and
+					eval_expression ($sentence['condition'], $context) and
 					processAdjustmentSentence ($sentence['modlist'], $expl_tags)
 				) // recalculate implicit chain only after actual change, not just on matched condition
+				{
 					$impl_tags = getImplicitTags ($expl_tags); // recalculate
+					$context = array_merge ($const_base, $expl_tags, $impl_tags);
+					$context = reindexById ($context, 'tag', TRUE);
+				}
 				break;
 			default:
 				throw new RackTablesError ("Can't process sentence of unknown type '${sentence['type']}'", RackTablesError::INTERNAL);
@@ -469,10 +464,11 @@ function queryLDAPServer ($username, $password)
 {
 	global $LDAP_options;
 
-	if(extension_loaded('ldap') === FALSE)
+	if (extension_loaded ('ldap') === FALSE)
 		throw new RackTablesError ('LDAP misconfiguration. LDAP PHP Module is not installed.', RackTablesError::MISCONFIGURED);
 
-	$LDAP_CANT_CONNECT_CODES = array (
+	$ldap_cant_connect_codes = array
+	(
 		-1,			// Can't contact LDAP server error
 		-5,			// LDAP Timed out error
 		-11,		// LDAP connect error
@@ -500,15 +496,17 @@ function queryLDAPServer ($username, $password)
 			$tls = ldap_start_tls ($connect);
 			if ($LDAP_options['use_tls'] >= 2 && $tls == FALSE)
 			{
-				if (in_array (ldap_errno ($connect), $LDAP_CANT_CONNECT_CODES))
+				if (in_array (ldap_errno ($connect), $ldap_cant_connect_codes))
 					continue;
 				else
 					throw new RackTablesError ('LDAP misconfiguration: LDAP TLS required but not successfully negotiated.', RackTablesError::MISCONFIGURED);
 			}
+			$success_server = $server;
+			break;
 		}
 		else
 		{
-			if (@ldap_bind ($connect) || !in_array (ldap_errno ($connect), $LDAP_CANT_CONNECT_CODES))
+			if (@ldap_bind ($connect) || !in_array (ldap_errno ($connect), $ldap_cant_connect_codes))
 			{
 				$success_server = $server;
 				// Cleanup after check. This connection will be used below
