@@ -66,6 +66,9 @@ $image['Cut gray']['height'] = 22;
 $image['CUT']['path'] = 'pix/tango-edit-cut-32x32.png';
 $image['CUT']['width'] = 32;
 $image['CUT']['height'] = 32;
+$image['CUT gray']['path'] = 'pix/tango-edit-cut-32x32-gray.png';
+$image['CUT gray']['width'] = 32;
+$image['CUT gray']['height'] = 32;
 $image['add']['path'] = 'pix/tango-list-add.png';
 $image['add']['width'] = 16;
 $image['add']['height'] = 16;
@@ -287,11 +290,26 @@ $page_by_realm['ipv4rspool'] = 'ipv4slb';
 $page_by_realm['file'] = 'files';
 $page_by_realm['user'] = 'userlist';
 
+function getSelectOptions ($options, $selected_id = NULL)
+{
+	$ret = '';
+	foreach ($options as $key => $value)
+	{
+		$selected = is_array ($selected_id) ? in_array ($key, $selected_id) : $key == $selected_id;
+		$ret .= "<option value='${key}'" . ($selected ? ' selected' : '') . '>';
+		$ret .= stringForOption ($value) . '</option>';
+	}
+	return $ret;
+}
+
 function printSelect ($optionList, $select_attrs = array(), $selected_id = NULL)
 {
 	echo getSelect ($optionList, $select_attrs, $selected_id);
 }
 
+// $selected_id can be an array if you want to use multiselect
+// in order to use multiselect $select_attrs should contain smth like this:
+// 		[ 'name' => 'some_name[]', 'multiple' => 'multiple', 'size' => 5 ]
 // Input array keys are OPTION VALUEs and input array values are OPTION text.
 function getSelect ($optionList, $select_attrs = array(), $selected_id = NULL, $treat_single_special = TRUE)
 {
@@ -312,10 +330,7 @@ function getSelect ($optionList, $select_attrs = array(), $selected_id = NULL, $
 	$ret .= '<select';
 	foreach ($select_attrs as $attr_name => $attr_value)
 		$ret .= " ${attr_name}=${attr_value}";
-	$ret .= '>';
-	foreach ($optionList as $dict_key => $dict_value)
-		$ret .= "<option value='${dict_key}'" . ($dict_key == $selected_id ? ' selected' : '') . ">${dict_value}</option>";
-	$ret .= '</select>';
+	$ret .= '>' . getSelectOptions ($optionList, $selected_id) . '</select>';
 	return $ret;
 }
 
@@ -345,7 +360,13 @@ function getNiftySelect ($groupList, $select_attrs, $selected_id = NULL)
 	{
 		$ret .= "<optgroup label='${groupname}'>\n";
 		foreach ($groupdata as $dict_key => $dict_value)
-			$ret .= "<option value='${dict_key}'" . ($dict_key == $selected_id ? ' selected' : '') . ">${dict_value}</option>\n";
+		{
+			if (is_array ($selected_id))
+				$is_selected = in_array ($dict_key, $selected_id);
+			else
+				$is_selected = $dict_key == $selected_id;
+			$ret .= "<option value='${dict_key}'" . ($is_selected ? ' selected' : '') . ">${dict_value}</option>\n";
+		}
 		$ret .= "</optgroup>\n";
 	}
 	$ret .= "</select>\n";
@@ -595,7 +616,7 @@ function getRenderedIPv4NetCapacity ($range)
 			if ($mask = array_shift ($free_masks))
 			{
 				$cnt = count ($range['spare_ranges'][$mask]);
-				$free_text = ', ' . ($cnt > 1 ? "<small>${cnt}x</small>" : "") . "/$mask free";
+				$free_text = ', ' . ($cnt > 1 ? "<small>${cnt}&times;</small>" : "") . "/$mask free";
 			}
 		}
 		$text =  ip4_range_size ($range) . $free_text;
@@ -924,6 +945,11 @@ function getProgressBar ($percentage = 0, $theme = '', $inline = FALSE)
 }
 
 function renderNetVLAN ($cell)
+{
+	echo getRenderedNetVLAN ($cell);
+}
+
+function getRenderedNetVLAN ($cell)
 {
 	if (empty ($cell['8021q']))
 		return;
@@ -934,7 +960,7 @@ function renderNetVLAN ($cell)
 		$links[] = formatVLANAsShortLink ($vlan_info);
 	}
 	$noun = count ($cell['8021q']) > 1 ? 'VLANs' : 'VLAN';
-	echo "<div class='vlan'><strong><small>${noun}</small> " . implode (', ', $links) . '</strong></div>';
+	return "<div class='vlan'><strong><small>${noun}</small> " . implode (', ', $links) . '</strong></div>';
 }
 
 function includeJQueryUI ($do_css = TRUE)
@@ -987,6 +1013,15 @@ function serializeFileLinks ($links, $scissors = FALSE)
 	return $ret;
 }
 
+function makeFileDownloadButton ($file_id, $imgname = 'download')
+{
+	$href = makeHref (array ('module' => 'download', 'file_id' => $file_id));
+	$img = getImageHREF ($imgname, 'download file');
+	return "<a href='${href}'>${img}</a>";
+}
+
+// XXX: in new code please use one of the stringFor... functions below
+//
 // This is a dual-purpose formating function:
 // 1. Replace empty strings with nbsp.
 // 2. Cut strings that are too long: append "cut here" indicator and provide a mouse hint.
@@ -1006,6 +1041,51 @@ function niftyString ($string, $maxlen = 30, $usetags = TRUE)
 		($usetags ? '</span>' : '');
 }
 
+// "Some text, %s, some more text."
+function stringForLabel ($string, $maxlen = 30)
+{
+	// A tab counts for a space.
+	$string = preg_replace ("/\t/", ' ', $string);
+	$full = htmlspecialchars ($string, ENT_QUOTES, 'UTF-8');
+	if ($maxlen == 0 || mb_strlen ($string) <= $maxlen)
+		return $full;
+	$trimmed = mb_substr ($string, 0, $maxlen - 1);
+	$trimmed = htmlspecialchars ($trimmed, ENT_QUOTES, 'UTF-8');
+	$trimmed = str_replace (' ', '&nbsp;', $trimmed) . '&hellip;';
+	return "<span title='${full}'>${trimmed}</span>";
+}
+
+// "<TD>%s</TD>"
+function stringForTD ($string, $maxlen = 30)
+{
+	// The non-breaking space helps the TD to render properly.
+	return $string == '' ? '&nbsp;' : stringForLabel ($string, $maxlen);
+}
+
+// "<INPUT type=text value='%s'>"
+function stringForTextInputValue ($string, $maxlen = 30)
+{
+	if ($maxlen != 0)
+		$string = mb_substr ($string, 0, $maxlen);
+	return htmlspecialchars ($string, ENT_QUOTES, 'UTF-8');
+}
+
+// "<TEXTAREA>%s</TEXTAREA>"
+function stringForTextarea ($string)
+{
+	return htmlspecialchars ($string, ENT_QUOTES, 'UTF-8');
+}
+
+// <OPTION>%s</OPTION>
+function stringForOption ($string, $maxlen = 30)
+{
+	$string = preg_replace ("/\t/", ' ', $string);
+	if ($maxlen == 0 || mb_strlen ($string) <= $maxlen)
+		return htmlspecialchars ($string, ENT_QUOTES, 'UTF-8');
+	$string = mb_substr ($string, 0, $maxlen - 1);
+	return htmlspecialchars ($string, ENT_QUOTES, 'UTF-8') . '&hellip;';
+}
+
 function printTagsPicker ($preselect=NULL)
 {
 	global $taglist;
@@ -1074,4 +1154,13 @@ function makeIPAllocLink ($ip_bin, $alloc, $display_ifname = FALSE)
 		">" . ($display_ifname ? $alloc['name'] . '@' : '') . $object_name . "</a>";
 }
 
+function makeHtmlTag ($tagname, $attributes = array())
+{
+	$ret = '<' . $tagname;
+	foreach ($attributes as $key => $value)
+		$ret .= " $key=\"" . htmlspecialchars($value, ENT_QUOTES) . '"';
+	$ret .= '>';
+	return $ret;
+}
+
 ?>
