@@ -35,6 +35,19 @@ $delayauth = array();
 $svghandler = array();
 $ajaxhandler = array();
 
+/*
+Syntax:
+// Require file.php when processing tab "tab" of the page "page":
+$interface_requires['page-tab'] = array ('file.php');
+
+// Same, different notation:
+$interface_requires['page-tab'] = 'file.php';
+
+// Require three files for every tab of the page "page":
+$interface_requires['page-*'] = array ('file1.php', 'file2.php', 'file3.php');
+*/
+$interface_requires = array();
+
 $indexlayout = array
 (
 	array ('rackspace', 'depot', 'ipv4space', 'ipv6space'),
@@ -103,18 +116,22 @@ $tab['row']['default'] = 'View';
 $tab['row']['edit'] = 'Properties';
 $tab['row']['editracks'] = 'Manage racks';
 $tab['row']['newrack'] = 'Add new rack';
+$tab['row']['log'] = 'Log';
 $tab['row']['tagroller'] = 'Tag roller';
 $tab['row']['files'] = 'Files';
 $tabhandler['row']['default'] = 'renderRow';
 $tabhandler['row']['edit'] = 'renderEditRowForm';
 $tabhandler['row']['editracks'] = 'renderRackSortForm';
 $tabhandler['row']['newrack'] = 'renderNewRackForm';
+$tabhandler['row']['log'] = 'renderObjectLogEditor';
 $tabhandler['row']['tagroller'] = 'renderTagRollerForRow';
 $tabhandler['row']['files'] = 'renderFilesForEntity';
 $ophandler['row']['edit']['clearSticker'] = 'clearSticker';
 $ophandler['row']['edit']['deleteRow'] = 'deleteRow';
 $ophandler['row']['edit']['updateRow'] = 'updateRow';
 $ophandler['row']['newrack']['addRack'] = 'addRack';
+$ophandler['row']['log']['add'] = 'addObjectlog';
+$ophandler['row']['log']['del'] = 'tableHandler';
 $ophandler['row']['tagroller']['rollTags'] = 'rollTags';
 $ophandler['row']['files']['addFile'] = 'addFileToEntity';
 $ophandler['row']['files']['linkFile'] = 'linkFileToEntity';
@@ -143,6 +160,7 @@ $ophandler['rack']['problems']['updateRack'] = 'updateRackProblems';
 $ophandler['rack']['edit']['clearSticker'] = 'clearSticker';
 $ophandler['rack']['edit']['updateRack'] = 'updateRack';
 $ophandler['rack']['edit']['deleteRack'] = 'deleteRack';
+$ophandler['rack']['edit']['cleanRack'] = 'cleanRack';
 $ophandler['rack']['log']['add'] = 'addObjectlog';
 $ophandler['rack']['log']['del'] = 'tableHandler';
 $ophandler['rack']['tags']['saveTags'] = 'saveEntityTags';
@@ -493,6 +511,7 @@ $page['search']['bypass'] = 'q';
 $page['config']['title'] = 'Configuration';
 $page['config']['handler'] = 'renderConfigMainpage';
 $page['config']['parent'] = 'index';
+$interface_requires['config-*'] = 'interface-config.php';
 
 $page['userlist']['title'] = 'Local users';
 $page['userlist']['parent'] = 'config';
@@ -502,6 +521,7 @@ $tabhandler['userlist']['default'] = 'renderUserList';
 $tabhandler['userlist']['edit'] = 'renderUserListEditor';
 $ophandler['userlist']['edit']['updateUser'] = 'updateUser';
 $ophandler['userlist']['edit']['createUser'] = 'createUser';
+$interface_requires['userlist-*'] = 'interface-config.php';
 
 $page['user']['parent'] = 'userlist';
 $page['user']['bypass'] = 'user_id';
@@ -519,6 +539,7 @@ $ophandler['user']['tags']['saveTags'] = 'saveEntityTags';
 $ophandler['user']['files']['addFile'] = 'addFileToEntity';
 $ophandler['user']['files']['linkFile'] = 'linkFileToEntity';
 $ophandler['user']['files']['unlinkFile'] = 'unlinkFile';
+$interface_requires['user-*'] = 'interface-config.php';
 
 $page['perms']['title'] = 'Permissions';
 $page['perms']['parent'] = 'config';
@@ -527,6 +548,7 @@ $tab['perms']['edit'] = 'Edit';
 $tabhandler['perms']['default'] = 'renderRackCodeViewer';
 $tabhandler['perms']['edit'] = 'renderRackCodeEditor';
 $ophandler['perms']['edit']['saveRackCode'] = 'saveRackCode';
+$interface_requires['perms-*'] = 'interface-config.php';
 
 $page['parentmap']['title'] = 'Object container compatibility';
 $page['parentmap']['parent'] = 'config';
@@ -536,6 +558,7 @@ $tabhandler['parentmap']['default'] = 'renderObjectParentCompatViewer';
 $tabhandler['parentmap']['edit'] = 'renderObjectParentCompatEditor';
 $ophandler['parentmap']['edit']['add'] = 'tableHandler';
 $ophandler['parentmap']['edit']['del'] = 'tableHandler';
+$interface_requires['parentmap-*'] = 'interface-config.php';
 
 $page['portmap']['title'] = 'Port compatibility';
 $page['portmap']['parent'] = 'config';
@@ -547,6 +570,7 @@ $ophandler['portmap']['edit']['add'] = 'addOIFCompat';
 $ophandler['portmap']['edit']['del'] = 'delOIFCompat';
 $ophandler['portmap']['edit']['addPack'] = 'addOIFCompatPack';
 $ophandler['portmap']['edit']['delPack'] = 'delOIFCompatPack';
+$interface_requires['portmap-*'] = 'interface-config.php';
 
 $page['portifcompat']['title'] = 'Enabled port types';
 $page['portifcompat']['parent'] = 'config';
@@ -558,6 +582,7 @@ $ophandler['portifcompat']['edit']['add'] = 'tableHandler';
 $ophandler['portifcompat']['edit']['del'] = 'tableHandler';
 $ophandler['portifcompat']['edit']['addPack'] = 'addIIFOIFCompatPack';
 $ophandler['portifcompat']['edit']['delPack'] = 'delIIFOIFCompatPack';
+$interface_requires['portifcompat-*'] = 'interface-config.php';
 
 $page['portoifs']['title'] = 'Port outer interfaces';
 $page['portoifs']['parent'] = 'config';
@@ -568,6 +593,7 @@ $tabhandler['portoifs']['edit'] = 'renderPortOIFEditor';
 $ophandler['portoifs']['edit']['add'] = 'tableHandler';
 $ophandler['portoifs']['edit']['del'] = 'tableHandler';
 $ophandler['portoifs']['edit']['upd'] = 'tableHandler';
+$interface_requires['portoifs-*'] = 'interface-config.php';
 
 $page['attrs']['title'] = 'Attributes';
 $page['attrs']['parent'] = 'config';
@@ -582,6 +608,7 @@ $ophandler['attrs']['editattrs']['del'] = 'tableHandler';
 $ophandler['attrs']['editattrs']['upd'] = 'tableHandler';
 $ophandler['attrs']['editmap']['add'] = 'supplementAttrMap';
 $ophandler['attrs']['editmap']['del'] = 'tableHandler';
+$interface_requires['attrs-*'] = 'interface-config.php';
 
 $page['dict']['title'] = 'Dictionary';
 $page['dict']['parent'] = 'config';
@@ -592,6 +619,7 @@ $tabhandler['dict']['chapters'] = 'renderChaptersEditor';
 $ophandler['dict']['chapters']['add'] = 'tableHandler';
 $ophandler['dict']['chapters']['del'] = 'tableHandler';
 $ophandler['dict']['chapters']['upd'] = 'tableHandler';
+$interface_requires['dict-*'] = 'interface-config.php';
 
 $page['chapter']['parent'] = 'dict';
 $page['chapter']['bypass'] = 'chapter_no';
@@ -603,6 +631,7 @@ $tabhandler['chapter']['edit'] = 'renderChapterEditor';
 $ophandler['chapter']['edit']['add'] = 'tableHandler';
 $ophandler['chapter']['edit']['del'] = 'tableHandler';
 $ophandler['chapter']['edit']['upd'] = 'tableHandler';
+$interface_requires['chapter-*'] = 'interface-config.php';
 
 $page['ui']['title'] = 'User interface';
 $page['ui']['parent'] = 'config';
@@ -614,16 +643,22 @@ $tabhandler['ui']['edit'] = 'renderConfigEditor';
 $tabhandler['ui']['reset'] = 'renderUIResetForm';
 $ophandler['ui']['edit']['upd'] = 'updateUI';
 $ophandler['ui']['reset']['go'] = 'resetUIConfig';
+$interface_requires['ui-*'] = 'interface-config.php';
 
 $page['tagtree']['title'] = 'Tag tree';
 $page['tagtree']['parent'] = 'config';
 $tab['tagtree']['default'] = 'View';
 $tab['tagtree']['edit'] = 'Edit';
+$tab['tagtree']['resolve'] = 'Circular references';
 $tabhandler['tagtree']['default'] = 'renderTagTree';
 $tabhandler['tagtree']['edit'] = 'renderTagTreeEditor';
+$tabhandler['tagtree']['resolve'] = 'renderGraphCycleResolver';
 $ophandler['tagtree']['edit']['createTag'] = 'tableHandler';
 $ophandler['tagtree']['edit']['destroyTag'] = 'tableHandler';
 $ophandler['tagtree']['edit']['updateTag'] = 'updateTag';
+$ophandler['tagtree']['resolve']['updateTag'] = 'updateTag';
+$trigger['tagtree']['resolve'] = 'triggerGraphCycleResolver';
+$interface_requires['tagtree-*'] = 'interface-config.php';
 
 $page['myaccount']['title'] = 'My account';
 $page['myaccount']['parent'] = 'config';
@@ -640,6 +675,7 @@ $ophandler['myaccount']['mypassword']['changeMyPassword'] = 'changeMyPassword';
 $ophandler['myaccount']['interface']['upd'] = 'saveMyPreferences';
 $ophandler['myaccount']['interface']['reset'] = 'resetMyPreference';
 $ophandler['myaccount']['qlinks']['save'] = 'saveQuickLinks';
+$interface_requires['myaccount-*'] = 'interface-config.php';
 
 $page['cacti']['title'] = 'Cacti';
 $page['cacti']['parent'] = 'config';
@@ -650,6 +686,7 @@ $tabhandler['cacti']['servers'] = 'renderCactiServersEditor';
 $ophandler['cacti']['servers']['add'] = 'tableHandler';
 $ophandler['cacti']['servers']['del'] = 'tableHandler';
 $ophandler['cacti']['servers']['upd'] = 'tableHandler';
+$interface_requires['cacti-*'] = 'interface-config.php';
 
 $page['munin']['title'] = 'Munin';
 $page['munin']['parent'] = 'config';
@@ -660,6 +697,7 @@ $tabhandler['munin']['servers'] = 'renderMuninServersEditor';
 $ophandler['munin']['servers']['add'] = 'tableHandler';
 $ophandler['munin']['servers']['del'] = 'tableHandler';
 $ophandler['munin']['servers']['upd'] = 'tableHandler';
+$interface_requires['munin-*'] = 'interface-config.php';
 
 $page['cableconf']['title'] = 'Patch cables';
 $page['cableconf']['parent'] = 'config';
@@ -683,6 +721,7 @@ $ophandler['cableconf']['conncompat']['add'] = 'tableHandler';
 $ophandler['cableconf']['conncompat']['del'] = 'tableHandler';
 $ophandler['cableconf']['oifcompat']['add'] = 'tableHandler';
 $ophandler['cableconf']['oifcompat']['del'] = 'tableHandler';
+$interface_requires['cableconf-*'] = 'interface-cables.php';
 
 $page['reports']['title'] = 'Reports';
 $page['reports']['parent'] = 'index';
@@ -705,6 +744,8 @@ $tabhandler['reports']['8021q'] = 'render8021QReport';
 $tabhandler['reports']['warranty'] = 'renderExpirations';
 $tabhandler['reports']['integrity'] = 'renderDataIntegrityReport';
 $tabhandler['reports']['local'] = 'renderLocalReports';
+$interface_requires['reports-rackcode'] = 'code.php';
+$interface_requires['reports-*'] = 'interface-reports.php';
 
 $page['files']['title'] = 'Files';
 $page['files']['parent'] = 'index';
@@ -748,7 +789,7 @@ $tabhandler['8021q']['vdlist'] = 'renderVLANDomainListEditor';
 $tabhandler['8021q']['vstlist'] = 'renderVSTListEditor';
 $ophandler['8021q']['vdlist']['add'] = 'createVLANDomain';
 $ophandler['8021q']['vdlist']['del'] = 'tableHandler';
-$ophandler['8021q']['vdlist']['upd'] = 'tableHandler';
+$ophandler['8021q']['vdlist']['upd'] = 'updateVLANDomain';
 $ophandler['8021q']['vstlist']['add'] = 'tableHandler';
 $ophandler['8021q']['vstlist']['del'] = 'tableHandler';
 $ophandler['8021q']['vstlist']['upd'] = 'tableHandler';
@@ -845,8 +886,9 @@ $ophandler['cables']['heaps']['upd'] = 'tableHandler';
 $ophandler['cables']['amount']['dec'] = 'consumePatchCable';
 $ophandler['cables']['amount']['inc'] = 'replenishPatchCable';
 $ophandler['cables']['amount']['set'] = 'setPatchCableAmount';
+$interface_requires['cables-*'] = 'interface-cables.php';
 
-$ajaxhandler['get-tag-select'] = 'getTagSelectAJAX';
+$ajaxhandler['get-parent-node-options'] = 'getParentNodeOptionsAJAX';
 $ajaxhandler['get-location-select'] = 'getLocationSelectAJAX';
 $ajaxhandler['verifyCode'] = 'verifyCodeAJAX';
 $ajaxhandler['get-port-link'] = 'getPortInfoAJAX';
