@@ -91,6 +91,7 @@ $breedfunc = array
 	'ftos8-getallconf-main'    => 'ftos8SpotConfigText',
 	'air12-xlatepushq-main'    => 'air12TranslatePushQueue',
 	'air12-getallconf-main'    => 'ios12SpotConfigText',
+	'air12-getcdpstatus-main'  => 'ios12ReadCDPStatus',
 	'eos4-getallconf-main'     => 'eos4SpotConfigText',
 	'eos4-getmaclist-main'     => 'eos4ReadMacList',
 	'eos4-getportmaclist-main' => 'eos4ReadMacList',
@@ -647,6 +648,18 @@ function callScript ($gwname, $params, $in, &$out, &$errors)
 	return proc_close ($child);
 }
 
+// returns the empty structure to be returned from getRunning8021QConfig
+function constructRunning8021QConfig()
+{
+	return array
+	(
+		'vlanlist' => array(),   // unindexed list of integer VIDs
+		'portdata' => array(),   // portconf structures indexed by portname
+		'portconfig' => array(), // config text lines indexed by portname.
+		'vlannames' => array(),  // vlan names indexed by VID
+	);
+}
+
 function getRunning8021QConfig ($object_id)
 {
 	$ret = queryDevice ($object_id, 'get8021q');
@@ -698,6 +711,8 @@ function shortenIfName ($if_name, $breed = NULL, $object_id = NULL)
 	{
 		case 'ios12':
 			return ios12ShortenIfName_real ($if_name);
+		case 'nxos4':
+			return nxos4ShortenIfName ($if_name);
 		case 'vrp53':
 		case 'vrp55':
 			return vrp5xShortenIfName ($if_name);
@@ -721,6 +736,16 @@ function ios12ShortenIfName_real ($ifname)
 	return $ifname;
 }
 
+function nxos4ShortenIfName ($ifname)
+{
+	$ifname = preg_replace ('@^(Ethernet|Eth)(.+)$@', 'e\\2', $ifname);
+	$ifname = preg_replace ('@^port-channel(.+)$@i', 'po\\1', $ifname);
+	$ifname = preg_replace ('@^mgmt(.+)$@i', 'mgmt\\1', $ifname);
+	$ifname = strtolower ($ifname);
+	$ifname = preg_replace ('/^(e|po|mgmt)\s+(\d.*)/', '$1$2', $ifname);
+	return $ifname;
+}
+
 function vrp5xShortenIfName ($ifname)
 {
 	if (preg_match ('@^eth-trunk(\d+)$@i', $ifname, $m))
@@ -750,6 +775,7 @@ function iosxr4ShortenIfName ($ifname)
 	$ifname = preg_replace ('@^GigabitEthernet\s*(.+)$@', 'gi\\1', $ifname);
 	$ifname = preg_replace ('@^TenGigE\s*(.*)$@', 'te\\1', $ifname);
 	$ifname = preg_replace ('@^BE\s*(\d+)$@', 'bundle-ether\\1', $ifname);
+	$ifname = preg_replace ('@^HundredGigE\s*(.+)$@i', 'hu\\1', $ifname);
 	$ifname = strtolower ($ifname);
 	return $ifname;
 }
@@ -762,12 +788,12 @@ function ios12ShortenIfName ($ifname)
 		return "Eth-Trunk${m[1]}";
 	$ifname = preg_replace ('@^(?:[Ee]thernet|Eth)(.+)$@', 'e\\1', $ifname);
 	$ifname = preg_replace ('@^FastEthernet(.+)$@', 'fa\\1', $ifname);
-	$ifname = preg_replace ('@^(?:GigabitEthernet|GE)(.+)$@', 'gi\\1', $ifname);
+	$ifname = preg_replace ('@^(?:GigabitEthernet|GE)\s*(.+)$@', 'gi\\1', $ifname);
 	$ifname = preg_replace ('@^TenGigabitEthernet(.+)$@', 'te\\1', $ifname);
 	$ifname = preg_replace ('@^port-channel(.+)$@i', 'po\\1', $ifname);
 	$ifname = preg_replace ('@^(?:XGigabitEthernet|XGE)(.+)$@', 'xg\\1', $ifname);
 	$ifname = preg_replace ('@^LongReachEthernet(.+)$@', 'lo\\1', $ifname);
-	$ifname = preg_replace ('@^Management(.+)$@', 'ma\\1', $ifname);
+	$ifname = preg_replace ('@^Management(?:Ethernet)\s(.+)$@', 'ma\\1', $ifname);
 	$ifname = preg_replace ('@^Et(\d.*)$@', 'e\\1', $ifname);
 	$ifname = preg_replace ('@^TenGigE(.*)$@', 'te\\1', $ifname); // IOS XR4
 	$ifname = preg_replace ('@^Mg(?:mtEth)?(.*)$@', 'mg\\1', $ifname); // IOS XR4
