@@ -12,10 +12,10 @@ function renderSLBDefConfig()
 	startPortlet ('SLB default configs');
 	printOpFormIntro ('save');
 	echo '<table cellspacing=0 cellpadding=5 align=center>';
-	echo '<tr><th class=tdright>VS config</th><td colspan=2><textarea name=vsconfig rows=10 cols=80>' . htmlspecialchars($defaults['vsconfig']) . '</textarea></td>';
+	echo '<tr><th class=tdright>VS config</th><td colspan=2><textarea name=vsconfig rows=10 cols=80>' . stringForTextarea ($defaults['vsconfig']) . '</textarea></td>';
 	echo '<td rowspan=2>';
 	echo '</td></tr>';
-	echo '<tr><th class=tdright>RS config</th><td colspan=2><textarea name=rsconfig rows=10 cols=80>' . htmlspecialchars($defaults['rsconfig']) . '</textarea></td></tr>';
+	echo '<tr><th class=tdright>RS config</th><td colspan=2><textarea name=rsconfig rows=10 cols=80>' . stringForTextarea ($defaults['rsconfig']) . '</textarea></td></tr>';
 	echo '</form></table>';
 	printImageHREF ('SAVE', 'Save changes', TRUE);
 	finishPortlet();
@@ -53,7 +53,7 @@ function renderSLBEntityCell ($cell, $highlighted = FALSE)
 	case 'ipv4rspool':
 		echo "<tr><td>";
 		echo "<a class='$a_class' href='index.php?page=ipv4rspool&pool_id=${cell['id']}'>";
-		echo !strlen ($cell['name']) ? "ANONYMOUS pool [${cell['id']}]" : niftyString ($cell['name']);
+		echo !strlen ($cell['name']) ? "ANONYMOUS pool [${cell['id']}]" : stringForTD ($cell['name']);
 		echo "</a></td></tr><tr><td>";
 		printImageHREF ('RS pool');
 		if ($cell['rscount'])
@@ -236,14 +236,14 @@ function renderSLBTripletsEdit ($cell)
 			echo getOpLink ($del_params, '', 'DELETE', 'Unconfigure');
 			echo "</td><td class=tdleft valign=bottom>";
 			renderSLBEntityCell ($cells[0]);
-			echo "</td><td>VS config &darr;<br><textarea name=vsconfig rows=5 cols=70>" . htmlspecialchars ($slb->slb['vsconfig']) . "</textarea></td>";
+			echo "</td><td>VS config &darr;<br><textarea name=vsconfig rows=5 cols=70>" . stringForTextarea ($slb->slb['vsconfig']) . "</textarea></td>";
 			echo '<td class=tdleft rowspan=2 valign=middle>';
 			printImageHREF ('SAVE', 'Save changes', TRUE);
 			echo "</td>";
 			echo "</tr><tr class=row_${order}><td class=tdleft valign=top>";
 			renderSLBEntityCell ($cells[1]);
 			echo '</td><td>';
-			echo "<textarea name=rsconfig rows=5 cols=70>" . htmlspecialchars ($slb->slb['rsconfig']) . "</textarea><br>RS config &uarr;";
+			echo "<textarea name=rsconfig rows=5 cols=70>" . stringForTextarea ($slb->slb['rsconfig']) . "</textarea><br>RS config &uarr;";
 			echo "<div style='float:left; margin-top:10px'><label><input name=prio type=text size=10 value=\"" . htmlspecialchars ($slb->slb['prio']) . "\"> &larr; Priority</label></div>";
 			echo '</td></tr></form>';
 			$order = $nextorder[$order];
@@ -358,10 +358,10 @@ function prepareRealServersTable ($rs_list)
 		if ($key != 'rsip')
 			unset ($columns[$key]);
 	return array
-		(
-			'columns' => $columns,
-			'rows' => $rs_list,
-		);
+	(
+		'columns' => $columns,
+		'rows' => $rs_list,
+	);
 }
 
 function renderEditRSList ($rs_list)
