@@ -70,9 +70,7 @@ function renderVS ($vsid)
 
 function renderTripletForm ($bypass_id)
 {
-	global $pageno, $etype_by_pageno;
-	$cell = spotEntity ($etype_by_pageno[$pageno], $bypass_id);
-	renderSLBTriplets2 ($cell, TRUE);
+	renderSLBTriplets2 (spotEntity (etypeByPageno(), $bypass_id), TRUE);
 }
 
 // either $port of $vip argument should be NULL
@@ -94,9 +92,9 @@ function renderPopupTripletForm ($triplet, $port, $vip, $row)
 		echo '<p><label>Priority:<br><input type=text name=prio value="'  . htmlspecialchars (is_array ($row) ? $row['prio'] : '', ENT_QUOTES) . '"></label>';
 	}
 	echo '<p><label>VS config:<br>';
-	echo '<textarea name=vsconfig rows=3 cols=80>' . htmlspecialchars (is_array ($row) ? $row['vsconfig'] : '') . '</textarea></label>';
+	echo '<textarea name=vsconfig rows=3 cols=80>' . (is_array ($row) ? stringForTextarea ($row['vsconfig']) : '') . '</textarea></label>';
 	echo '<p><label>RS config:<br>';
-	echo '<textarea name=rsconfig rows=3 cols=80>' . htmlspecialchars (is_array ($row) ? $row['rsconfig'] : '') . '</textarea></label>';
+	echo '<textarea name=rsconfig rows=3 cols=80>' . (is_array ($row) ? stringForTextarea ($row['rsconfig']) : '') . '</textarea></label>';
 	echo '<p align=center>' . getImageHREF ('SAVE', 'Save changes', TRUE);
 	echo '</form>';
 }
@@ -109,9 +107,9 @@ function renderPopupVSPortForm ($port, $used = 0)
 	echo '<p align=center>';
 	echo getOpLink (array ('op' => 'delPort') + $keys, $title, 'destroy', '', ($used ? 'del-used-slb' : '') );
 	echo '<p><label>VS config:<br>';
-	echo '<textarea name=vsconfig rows=3 cols=80>' . htmlspecialchars ($port['vsconfig']) . '</textarea></label>';
+	echo '<textarea name=vsconfig rows=3 cols=80>' . stringForTextarea ($port['vsconfig']) . '</textarea></label>';
 	echo '<p><label>RS config:<br>';
-	echo '<textarea name=rsconfig rows=3 cols=80>' . htmlspecialchars ($port['rsconfig']) . '</textarea></label>';
+	echo '<textarea name=rsconfig rows=3 cols=80>' . stringForTextarea ($port['rsconfig']) . '</textarea></label>';
 	echo '<p align=center>' . getImageHREF ('SAVE', 'Save changes', TRUE);
 	echo '</form>';
 }
@@ -124,9 +122,9 @@ function renderPopupVSVIPForm ($vip, $used = 0)
 	echo '<p align=center>';
 	echo getOpLink (array ('op' => 'delIP', 'ip' => $fmt_ip), $title, 'destroy', '', ($used ? 'del-used-slb' : '') );
 	echo '<p><label>VS config:<br>';
-	echo '<textarea name=vsconfig rows=3 cols=80>' . htmlspecialchars ($vip['vsconfig']) . '</textarea></label>';
+	echo '<textarea name=vsconfig rows=3 cols=80>' . stringForTextarea ($vip['vsconfig']) . '</textarea></label>';
 	echo '<p><label>RS config:<br>';
-	echo '<textarea name=rsconfig rows=3 cols=80>' . htmlspecialchars ($vip['rsconfig']) . '</textarea></label>';
+	echo '<textarea name=rsconfig rows=3 cols=80>' . stringForTextarea ($vip['rsconfig']) . '</textarea></label>';
 	echo '<p align=center>' . getImageHREF ('SAVE', 'Save changes', TRUE);
 	echo '</form>';
 }
@@ -145,8 +143,8 @@ function renderEditVS ($vs_id)
 	echo "<tr><th class=tdright>Tags:</th><td class=tdleft>";
 	printTagsPicker ();
 	echo "</td></tr>\n";
-	echo '<tr><th class=tdright>VS config:</th><td class=tdleft><textarea name=vsconfig rows=3 cols=80>' . htmlspecialchars ($vsinfo['vsconfig']) . '</textarea></td></tr>';
-	echo '<tr><th class=tdright>RS config:</th><td class=tdleft><textarea name=rsconfig rows=3 cols=80>' . htmlspecialchars ($vsinfo['rsconfig']) . '</textarea></td></tr>';
+	echo '<tr><th class=tdright>VS config:</th><td class=tdleft><textarea name=vsconfig rows=3 cols=80>' . stringForTextarea ($vsinfo['vsconfig']) . '</textarea></td></tr>';
+	echo '<tr><th class=tdright>RS config:</th><td class=tdleft><textarea name=rsconfig rows=3 cols=80>' . stringForTextarea ($vsinfo['rsconfig']) . '</textarea></td></tr>';
 	echo '<tr><th></th><th>';
 	printImageHREF ('SAVE', 'Save changes', TRUE);
 	// delete link
@@ -260,8 +258,8 @@ function groupTriplets ($tr_list)
 			}
 			else
 			{
-				foreach ($group as &$tr_ref)
-					$tr_ref['span'][$group_by] = count ($group);
+				foreach (array_keys ($group) as $key)
+					$group[$key]['span'][$group_by] = count ($group);
 				foreach ($self ($group) as $tr)
 					if (isset ($index[$tr['key']]))
 					{
@@ -343,7 +341,13 @@ function renderSLBTriplets2 ($cell, $editable = FALSE, $hl_ip = NULL)
 	{
 		$vs_cell = spotEntity ('ipvs', $slb['vs_id']);
 		amplifyCell ($vs_cell);
-		echo "<tr valign=top class='row_${order} triplet-row'>";
+		echo makeHtmlTag ('tr', array(
+			'valign' => 'top',
+			'class' => "row_${order} triplet-row",
+			'data-object_id' => $slb['object_id'],
+			'data-vs_id' => $slb['vs_id'],
+			'data-rspool_id' => $slb['rspool_id'],
+		));
 		echo '<td><a href="#" onclick="' . "slb_config_preview(event, ${slb['object_id']}, ${slb['vs_id']}, ${slb['rspool_id']}); return false" . '">' . getImageHREF ('Zoom', 'config preview') . '</a></td>';
 		foreach (array_keys ($headers) as $realm)
 		{
