@@ -20,6 +20,7 @@ try {
 		// set by local.php get lost
 		require_once 'inc/init.php';
 		prepareNavigation();
+		requireExtraFiles ($interface_requires);
 		// Security context is built on the requested page/tab/bypass data,
 		// do not override.
 		fixContext();
@@ -271,6 +272,7 @@ try {
 
 	case 'upgrade':
 		require_once 'inc/config.php'; // for CODE_VERSION
+		require_once 'inc/database.php';
 		require_once 'inc/dictionary.php';
 		require_once 'inc/functions.php'; // for ip translation functions
 		require_once 'inc/upgrade.php';
